package cn.dg32z.lon.manager.logs.dao;

import cn.dg32z.libs.chengzhiya.task.mhdfscheduler.scheduler.MHDFScheduler;
import cn.dg32z.libs.com.mongodb.client.MongoCollection;
import cn.dg32z.libs.com.mongodb.client.MongoCursor;
import cn.dg32z.libs.org.bson.Document;
import cn.dg32z.lon.LonAntiCheat;
import cn.dg32z.lon.PluginLoader;
import cn.dg32z.lon.manager.logs.entity.Violation;
import cn.dg32z.lon.manager.logs.interfaces.ViolationManager;
import cn.dg32z.lon.manager.plugin.init.HookInit;
import cn.dg32z.lon.player.PlayerData;
import java.util.ArrayList;
import java.util.List;
import java.util.UUID;
import org.bukkit.OfflinePlayer;

/* loaded from: cn_dg32z_lon_manager_logs_dao.jar:cn/dg32z/lon/manager/logs/dao/ViolationMongoDBUtil.class */
public final class ViolationMongoDBUtil implements ViolationManager {
    private final MongoCollection<Document> violationsCollection;

    public ViolationMongoDBUtil(MongoCollection<Document> violationsCollection) {
        this.violationsCollection = violationsCollection;
    }

    public void logAlertSync(OfflinePlayer offlinePlayer, PlayerData player, boolean exp, String verbose, String checkName, int violations, String description, String ping, boolean lagging, boolean moveLagging, String tps, String brand, String version) {
        MHDFScheduler.getAsyncScheduler().runTask(LonAntiCheat.getInstance(), task -> {
            try {
                Document document = new Document().append("server", HookInit.getPlaceholderAPIHook().setPlaceholders(offlinePlayer, PluginLoader.INSTANCE.getMessageUtils().i18nWithOutPrefix("database-manager.server-name"))).append("uuid", player.getUniqueId()).append("player_name", player.getName()).append("check_name", checkName).append("exp", Boolean.valueOf(exp)).append("verbose", verbose).append("vl", Integer.valueOf(violations)).append("description", description).append("created_at", Long.valueOf(System.currentTimeMillis())).append("ping", ping).append("lagging", Boolean.valueOf(lagging)).append("move_lagging", Boolean.valueOf(moveLagging)).append("tps", tps).append("brand", brand).append("version", version);
                this.violationsCollection.insertOne(document);
            } catch (Exception ex) {
                throw new RuntimeException("MongoDB 插入Violation失败", ex);
            }
        });
    }

    public long getLogCount(OfflinePlayer player) {
        try {
            return this.violationsCollection.countDocuments(new Document("uuid", player.getUniqueId()));
        } catch (Exception ex) {
            throw new RuntimeException("MongoDB 查询Violation数量失败", ex);
        }
    }

    public List<Violation> getViolations(OfflinePlayer player, int page, int limit) {
        try {
            List<Violation> violations = new ArrayList<>();
            Document document = new Document().append("uuid", player.getUniqueId());
            MongoCursor it = this.violationsCollection.find(document).sort(new Document("created_at", -1)).skip((page - 1) * limit).limit(limit).iterator();
            while (it.hasNext()) {
                Document doc = (Document) it.next();
                violations.add(new Violation(doc.getString("server"), UUID.fromString(doc.getString("uuid")), doc.getString("player_name"), doc.getString("check_name"), doc.getString("verbose"), doc.getInteger("vl").intValue(), doc.getString("description"), doc.getBoolean("exp").booleanValue(), doc.getLong("created_at").longValue(), doc.getString("ping"), doc.getBoolean("lagging").booleanValue(), doc.getBoolean("move_lagging").booleanValue(), doc.getString("tps"), doc.getString("brand"), doc.getString("version")));
            }
            return violations;
        } catch (Exception ex) {
            throw new RuntimeException("MongoDB 查询Violation失败", ex);
        }
    }

    public void clearLogs(OfflinePlayer player) {
        MHDFScheduler.getAsyncScheduler().runTask(LonAntiCheat.getInstance(), task -> {
            try {
                Document document = new Document().append("uuid", player.getUniqueId());
                this.violationsCollection.deleteMany(document);
            } catch (Exception ex) {
                throw new RuntimeException("MongoDB 清除指定玩家日志失败", ex);
            }
        });
    }

    public void clearAllLogs() {
        MHDFScheduler.getAsyncScheduler().runTask(LonAntiCheat.getInstance(), task -> {
            try {
                this.violationsCollection.deleteMany(new Document());
            } catch (Exception ex) {
                throw new RuntimeException("MongoDB 清除全部日志失败", ex);
            }
        });
    }
}
